@@ -14,7 +14,14 @@
 # limitations under the License.
 #
 
-__all__ = ["chacha20_aead_decrypt", "chacha20_aead_encrypt", "SrpClient", "SrpServer"]
+__all__ = [
+    "chacha20_aead_decrypt",
+    "chacha20_aead_encrypt",
+    "hkdf_derive",
+    "SrpClient",
+    "SrpServer",
+]
 
 from .chacha20poly1305 import chacha20_aead_decrypt, chacha20_aead_encrypt
+from .hkdf import hkdf_derive
 from .srp import SrpClient, SrpServer
