@@ -124,3 +124,96 @@ class TargetHeaterCoolerStateValues(enum.IntEnum):
     AUTOMATIC = 0
     HEAT = 1
     COOL = 2
+
+
+class StreamingStatusValues(enum.IntEnum):
+    """The current streaming state of a camera."""
+
+    AVAILABLE = 0
+    IN_USE = 1
+    UNAVAILABLE = 2
+
+
+class SessionControlCommandValues(enum.IntEnum):
+    """Session control commands."""
+
+    END_SESSION = 0
+    START_SESSION = 1
+    SUSPEND_SESSION = 2
+    RESUME_SESSION = 3
+    RECONFIGURE_SESSION = 4
+
+
+class VideoCodecTypeValues(enum.IntEnum):
+
+    H264 = 0
+
+
+class ProfileIDValues(enum.IntEnum):
+
+    """
+    The type of H.264 profile used.
+
+    3-255 are vendor specific.
+    """
+
+    CONTRAINED_BASELINE_PROFILE = 0
+    MAIN_PROFILE = 1
+    HIGH_PROFILE = 2
+
+
+class ProfileSupportLevelValues(enum.IntEnum):
+
+    """
+    3-255 are reserved by Apple.
+    """
+
+    THREE_ONE = 0
+    THREE_TWO = 1
+    FOUR = 2
+
+
+class PacketizationModeValues(enum.IntEnum):
+    """
+    1 - 255 are reserved by Apple.
+    """
+
+    NON_INTERLEAVED_MODE = 0
+
+
+class CVOEnabledValues(enum.IntEnum):
+
+    NOT_SUPPORTED = 0
+    SUPPORTED = 1
+
+
+class AudioCodecValues(enum.IntEnum):
+
+    """
+    7-255 reserved for Apple.
+    """
+
+    AAC_ELD = 2
+    OPUS = 3
+    AMR = 5
+    AMR_WB = 6
+
+
+class BitRateValues(enum.IntEnum):
+
+    VARIABLE = 0
+    CONSTANT = 1
+
+
+class SampleRateValues(enum.IntEnum):
+
+    EIGHT_KHZ = 0
+    SIXTEEN_KHZ = 1
+    TWENTY_FOUR_KHZ = 2
+
+
+class SRTPCryptoSuiteValues(enum.IntEnum):
+
+    AES_CM_128_HMAC_SHA1_80 = 0
+    AES_256_CM_HMAC_SHA1_80 = 1
+    DISABLED = 2
