@@ -7,14 +7,14 @@ def clamp_enum_to_char(all_valid_values: enum.IntEnum, char: Characteristic):
     """Clamp possible values of an enum to restrictions imposed by a manufacturer."""
     valid_values = set(all_valid_values)
 
-    if char.minValue:
+    if char.minValue is not None:
         valid_values = {
             target_state
             for target_state in valid_values
             if target_state >= char.minValue
         }
 
-    if char.maxValue:
+    if char.maxValue is not None:
         valid_values = {
             target_state
             for target_state in valid_values
